
if (CMAKE_VERSION VERSION_LESS 3.1.0)
    message(FATAL_ERROR "Qt 5 Gui module requires at least CMake version 3.1.0")
endif()


if(OVERRIDE_QT_VARIANT_PREFIX)
    if(OVERRIDE_QT_VARIANT_PREFIX STREQUAL none)
        unset(QT_VARIANT_PREFIX)
    else()
        set(QT_VARIANT_PREFIX ${OVERRIDE_QT_VARIANT_PREFIX})
    endif()
else()
    set(QT_VARIANT_PREFIX "Static")
endif()

get_filename_component(_qt5Gui_install_prefix "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# For backwards compatibility only. Use Qt5Gui_VERSION instead.
set(${QT_VARIANT_PREFIX}Qt5Gui_VERSION_STRING 5.13.0)

set(${QT_VARIANT_PREFIX}Qt5Gui_LIBRARIES ${QT_VARIANT_PREFIX}Qt5::Gui)

macro(_qt5_Gui_check_file_exists_static FILE)
    if(NOT EXISTS "${FILE}")
        message(FATAL_ERROR "The imported target \"${QT_VARIANT_PREFIX}Qt5::Gui\" references the file
   \"${FILE}\"
but this file does not exist.  Possible reasons include:
* The file was deleted, renamed, or moved to another location.
* An install or uninstall procedure did not complete successfully.
* The installation package was faulty and contained
   \"${CMAKE_CURRENT_LIST_FILE}\"
but not all the files it references.
")
    endif()
endmacro()

function(_qt5_Gui_process_prl_file prl_file_location Configuration lib_deps link_flags)
    set(_lib_deps)
    set(_link_flags)

    # prefer static libs
    set(CMAKE_FIND_LIBRARY_SUFFIXES .a .lib)
    set(CMAKE_FIND_LIBRARY_PREFIXES lib "")

    get_filename_component(_qt5_install_libs "${_qt5Gui_install_prefix}/lib" ABSOLUTE)

    if(EXISTS "${prl_file_location}")
        file(STRINGS "${prl_file_location}" _prl_strings REGEX "QMAKE_PRL_LIBS[ \t]*=")
        if(NOT _prl_strings)
            message(WARNING Prl file for Qt 5 module Gui does not contain QMAKE_PRL_LIBS. Was looking at "${prl_file_location}".)
            return()
        endif()
        string(REGEX REPLACE "QMAKE_PRL_LIBS[ \t]*=[ \t]*([^\n]*)" "\\1" _static_depends ${_prl_strings})
        string(REGEX REPLACE "[ \t]+" ";" _static_depends ${_static_depends})
        string(REGEX REPLACE "[ \t]+" ";" _standard_libraries "${CMAKE_CXX_STANDARD_LIBRARIES}")
        set(_search_paths)
        string(REPLACE "\$\$[QT_INSTALL_LIBS]" "${_qt5_install_libs}" _static_depends "${_static_depends}")
        foreach(_flag ${_static_depends})
            string(REPLACE "\"" "" _flag ${_flag})
            if(_flag MATCHES "^-l(.*)$")
                # Handle normal libraries passed as -lfoo
                set(_lib "${CMAKE_MATCH_1}")
                foreach(_standard_library ${_standard_libraries})
                    if(_standard_library MATCHES "^${_lib}(\\.lib|\\.a)?$")
                        set(_lib_is_default_linked TRUE)
                        break()
                    endif()
                endforeach()
                if (_lib_is_default_linked)
                    unset(_lib_is_default_linked)
                elseif(_lib MATCHES "^pthread$")
                    find_package(Threads REQUIRED)
                    list(APPEND _lib_deps Threads::Threads)
                else()
                    if(_search_paths)
                        find_library(_Qt5Gui_${Configuration}_${_lib}_PATH ${_lib} HINTS ${_search_paths} NO_DEFAULT_PATH)
                    endif()
                    find_library(_Qt5Gui_${Configuration}_${_lib}_PATH ${_lib})
                    mark_as_advanced(_Qt5Gui_${Configuration}_${_lib}_PATH)
                    if(_Qt5Gui_${Configuration}_${_lib}_PATH)
                        list(APPEND _lib_deps
                            ${_Qt5Gui_${Configuration}_${_lib}_PATH}
                        )
                    else()
                        message(FATAL_ERROR "Library not found: ${_lib}")
                    endif()
                endif()
            elseif(EXISTS "${_flag}")
                # The flag is an absolute path to an existing library
                list(APPEND _lib_deps "${_flag}")
            elseif(_flag MATCHES "^-L(.*)$")
                # Handle -Lfoo flags by putting their paths in the search path used by find_library above
                list(APPEND _search_paths "${CMAKE_MATCH_1}")
            else()
                # Handle all remaining flags by simply passing them to the linker
                list(APPEND _link_flags ${_flag})
            endif()
        endforeach()
    endif()

    string(REPLACE ";" " " _link_flags "${_link_flags}")
    set(${lib_deps} ${_lib_deps} PARENT_SCOPE)
    set(${link_flags} "SHELL:${_link_flags}" PARENT_SCOPE)
endfunction()

if(NOT COMMAND _qt5_add_dependencies)
    # add dependencies via imported targets so CMake does not mess with their (absolute) file path
    # which can be problematic with unwanted -Wl,-Bstatic or -Wl,-Bdynamic in the linker line
    function(_qt5_add_dependencies IMPORTED_TARGET_NAME IMPORTED_TARGET_CONFIG STATIC_DEPENDENCIES)
        set(DEPENDENCY_INDEX 0)
        unset(EXTRA_PATHS)
        unset(DEPENDENCY_TARGETS)

        foreach(LIBRARY_LOCATION ${STATIC_DEPENDENCIES})
            if (TARGET "${LIBRARY_LOCATION}")
                list(APPEND DEPENDENCY_TARGETS "${LIBRARY_LOCATION}")
                continue()
            endif()
            set(DEPENDENCY_NAME ${IMPORTED_TARGET_NAME}_DEPENDENCY_${DEPENDENCY_INDEX})
            if (NOT TARGET "${DEPENDENCY_NAME}")
                add_library(${DEPENDENCY_NAME} STATIC IMPORTED)
                set_property(TARGET ${DEPENDENCY_NAME} PROPERTY IMPORTED_LOCATION ${LIBRARY_LOCATION})
            endif()
            list(APPEND DEPENDENCY_TARGETS ${DEPENDENCY_NAME})
            math(EXPR DEPENDENCY_INDEX "${DEPENDENCY_INDEX} + 1")
        endforeach()

        if ("${IMPORTED_TARGET_CONFIG}" STREQUAL "ALL" OR "${IMPORTED_TARGET_CONFIG}" STREQUAL "RELEASE")
            set_property(TARGET ${IMPORTED_TARGET_NAME} PROPERTY INTERFACE_LINK_LIBRARIES ${DEPENDENCY_TARGETS})
        endif()
        if (NOT "${IMPORTED_TARGET_CONFIG}" STREQUAL "ALL")
            set_property(TARGET ${IMPORTED_TARGET_NAME} PROPERTY INTERFACE_LINK_LIBRARIES_${IMPORTED_TARGET_CONFIG} ${DEPENDENCY_TARGETS})
        endif()
    endfunction()
endif()

# ensure also regular/dynamic macro exists because it might be used in some extra config
if(NOT COMMAND _qt5_Gui_check_file_exists)
    macro(_qt5_Gui_check_file_exists FILE)
        _qt5_Gui_check_file_exists_static("${FILE}")
    endmacro()
endif()

macro(_populate_Gui_target_properties_static TARGET_NAME TARGET_CONFIG LIB_LOCATION IMPLIB_LOCATION)
    set_property(TARGET ${TARGET_NAME} APPEND PROPERTY IMPORTED_CONFIGURATIONS ${TARGET_CONFIG})


    set(imported_location "${_qt5Gui_install_prefix}/lib/${LIB_LOCATION}")


    set(_deps
        ${_Qt5Gui_LIB_DEPENDENCIES}
        ${_Qt5Gui_STATIC_${TARGET_CONFIG}_LIB_DEPENDENCIES}
    )

    set_target_properties("${TARGET_NAME}" PROPERTIES
        "IMPORTED_LOCATION_${TARGET_CONFIG}" ${imported_location}
    )
    _qt5_add_dependencies("${TARGET_NAME}" "${TARGET_CONFIG}" "${_deps}")
    if(NOT CMAKE_VERSION VERSION_LESS "3.13")
        set_target_properties("${TARGET_NAME}" PROPERTIES
            "INTERFACE_LINK_OPTIONS" "${_Qt5Gui_STATIC_${Configuration}_LINK_FLAGS}"
        )
    endif()

    set(imported_implib "${_qt5Gui_install_prefix}/lib/${IMPLIB_LOCATION}")
    _qt5_Gui_check_file_exists_static(${imported_implib})
    if(NOT "${IMPLIB_LOCATION}" STREQUAL "")
        set_target_properties(${QT_VARIANT_PREFIX}Qt5::Gui PROPERTIES
        "IMPORTED_IMPLIB_${TARGET_CONFIG}" ${imported_implib}
        )
    endif()
endmacro()

macro(_populate_Gui_plugin_target_dependencies_from_prl_file PLUGIN_TARGET_NAME PRL_FILE_LOCATION CONFIGURATION LIB_DIRECTORY LIB_LOCATION)
    _qt5_Gui_process_prl_file(
        "${PRL_FILE_LOCATION}"
        "${CONFIGURATION}"
        _Qt5Gui_STATIC_PLUGIN_${CONFIGURATION}_LIB_DEPENDENCIES
        _Qt5Gui_STATIC_PLUGIN_${CONFIGURATION}_LINK_FLAGS)
    _qt5_add_dependencies("${PLUGIN_TARGET_NAME}" ALL "${_Qt5Gui_STATIC_PLUGIN_${CONFIGURATION}_LIB_DEPENDENCIES}")
endmacro()

if(NOT TARGET ${QT_VARIANT_PREFIX}Qt5::Gui)
    set(_Qt5Gui_OWN_INCLUDE_DIRS "${_qt5Gui_install_prefix}/include/qt/" "${_qt5Gui_install_prefix}/include/qt/QtGui")
    set(${QT_VARIANT_PREFIX}Qt5Gui_PRIVATE_INCLUDE_DIRS
        "${_qt5Gui_install_prefix}/include/qt/QtGui/5.13.0"
        "${_qt5Gui_install_prefix}/include/qt/QtGui/5.13.0/QtGui"
    )
    include("${CMAKE_CURRENT_LIST_DIR}/ExtraSourceIncludes.cmake" OPTIONAL)

    foreach(_dir ${_Qt5Gui_OWN_INCLUDE_DIRS})
        _qt5_Gui_check_file_exists_static(${_dir})
    endforeach()

    # Only check existence of private includes if the Private component is
    # specified.
    list(FIND Qt5Gui_FIND_COMPONENTS Private _check_private)
    if (NOT _check_private STREQUAL -1)
        foreach(_dir ${Qt5Gui_PRIVATE_INCLUDE_DIRS})
            _qt5_Gui_check_file_exists_static(${_dir})
        endforeach()
    endif()

    set(${QT_VARIANT_PREFIX}Qt5Gui_INCLUDE_DIRS ${_Qt5Gui_OWN_INCLUDE_DIRS})

    set(${QT_VARIANT_PREFIX}Qt5Gui_DEFINITIONS -DQT_GUI_LIB)
    set(${QT_VARIANT_PREFIX}Qt5Gui_COMPILE_DEFINITIONS QT_GUI_LIB)
    set(_Qt5Gui_MODULE_DEPENDENCIES "Core")


    set(${QT_VARIANT_PREFIX}Qt5Gui_OWN_PRIVATE_INCLUDE_DIRS ${Qt5Gui_PRIVATE_INCLUDE_DIRS})

    set(_Qt5Gui_FIND_DEPENDENCIES_REQUIRED)
    if (${QT_VARIANT_PREFIX}Qt5Gui_FIND_REQUIRED)
        set(_Qt5Gui_FIND_DEPENDENCIES_REQUIRED REQUIRED)
    endif()
    set(_Qt5Gui_FIND_DEPENDENCIES_QUIET)
    if (Qt5Gui_FIND_QUIETLY)
        set(_Qt5Gui_DEPENDENCIES_FIND_QUIET QUIET)
    endif()
    set(_Qt5Gui_FIND_VERSION_EXACT)
    if (${QT_VARIANT_PREFIX}Qt5Gui_FIND_VERSION_EXACT)
        set(_Qt5Gui_FIND_VERSION_EXACT EXACT)
    endif()

    set(${QT_VARIANT_PREFIX}Qt5Gui_EXECUTABLE_COMPILE_FLAGS "")

    foreach(_module_dep ${_Qt5Gui_MODULE_DEPENDENCIES})
        if (NOT ${QT_VARIANT_PREFIX}Qt5${_module_dep}_FOUND)
            find_package(${QT_VARIANT_PREFIX}Qt5${_module_dep}
                5.13.0 ${_Qt5Gui_FIND_VERSION_EXACT}
                ${_Qt5Gui_DEPENDENCIES_FIND_QUIET}
                ${_Qt5Gui_FIND_DEPENDENCIES_REQUIRED}
                PATHS "${CMAKE_CURRENT_LIST_DIR}/.." NO_DEFAULT_PATH
            )
        endif()

        if (NOT ${QT_VARIANT_PREFIX}Qt5${_module_dep}_FOUND)
            set(${QT_VARIANT_PREFIX}Qt5Gui_FOUND False)
            return()
        endif()

        list(APPEND ${QT_VARIANT_PREFIX}Qt5Gui_INCLUDE_DIRS "${Qt5${_module_dep}_INCLUDE_DIRS}")
        list(APPEND ${QT_VARIANT_PREFIX}Qt5Gui_PRIVATE_INCLUDE_DIRS "${Qt5${_module_dep}_PRIVATE_INCLUDE_DIRS}")
        list(APPEND ${QT_VARIANT_PREFIX}Qt5Gui_DEFINITIONS ${Qt5${_module_dep}_DEFINITIONS})
        list(APPEND ${QT_VARIANT_PREFIX}Qt5Gui_COMPILE_DEFINITIONS ${Qt5${_module_dep}_COMPILE_DEFINITIONS})
        list(APPEND ${QT_VARIANT_PREFIX}Qt5Gui_EXECUTABLE_COMPILE_FLAGS ${Qt5${_module_dep}_EXECUTABLE_COMPILE_FLAGS})
    endforeach()
    list(REMOVE_DUPLICATES ${QT_VARIANT_PREFIX}Qt5Gui_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES ${QT_VARIANT_PREFIX}Qt5Gui_PRIVATE_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES ${QT_VARIANT_PREFIX}Qt5Gui_DEFINITIONS)
    list(REMOVE_DUPLICATES ${QT_VARIANT_PREFIX}Qt5Gui_COMPILE_DEFINITIONS)
    list(REMOVE_DUPLICATES ${QT_VARIANT_PREFIX}Qt5Gui_EXECUTABLE_COMPILE_FLAGS)

    set(_Qt5Gui_LIB_DEPENDENCIES "${QT_VARIANT_PREFIX}Qt5::Core")


    if(NOT Qt5_EXCLUDE_STATIC_DEPENDENCIES)

        _qt5_Gui_process_prl_file(
            "${_qt5Gui_install_prefix}/lib/Qt5Gui.static.prl" RELEASE
            _Qt5Gui_STATIC_RELEASE_LIB_DEPENDENCIES
            _Qt5Gui_STATIC_RELEASE_LINK_FLAGS
        )
    endif()

    set(TARGET_NAME ${QT_VARIANT_PREFIX}Qt5::Gui)
    add_library(${TARGET_NAME} STATIC IMPORTED)
    set_property(TARGET ${TARGET_NAME} PROPERTY IMPORTED_LINK_INTERFACE_LANGUAGES CXX)




    set_property(TARGET ${TARGET_NAME} PROPERTY
      INTERFACE_INCLUDE_DIRECTORIES ${_Qt5Gui_OWN_INCLUDE_DIRS})
    set_property(TARGET ${TARGET_NAME} PROPERTY
        INTERFACE_COMPILE_DEFINITIONS QT_STATIC;QT_DESIGNER_STATIC QT_GUI_LIB)

    set_property(TARGET ${TARGET_NAME} PROPERTY INTERFACE_QT_ENABLED_FEATURES accessibility;action;clipboard;colornames;cssparser;cursor;desktopservices;imageformat_xpm;draganddrop;opengl;imageformatplugin;highdpiscaling;im;image_heuristic_mask;image_text;imageformat_bmp;imageformat_jpeg;imageformat_png;imageformat_ppm;imageformat_xbm;movie;pdf;picture;sessionmanager;shortcut;standarditemmodel;systemtrayicon;tabletevent;texthtmlparser;textodfwriter;validator;vulkan;whatsthis;wheelevent)
    set_property(TARGET ${TARGET_NAME} PROPERTY INTERFACE_QT_DISABLED_FEATURES opengles2;dynamicgl;angle;combined-angle-lib;opengles3;opengles31;opengles32;openvg)

    # Find plugin targets
    file(GLOB pluginTargetsMaybe "${CMAKE_CURRENT_LIST_DIR}/*Qt5Gui_*.cmake")
    unset(pluginTargets)
    if(pluginTargetsMaybe)
        foreach(pluginTarget ${pluginTargetsMaybe})
            file(STRINGS ${pluginTarget} matched REGEX Qt5Gui_PLUGINS)
            if(matched)
                list(APPEND pluginTargets ${pluginTarget})
            endif()
        endforeach()
    endif()

    macro(_populate_Gui_plugin_properties_static TARGET_NAME PLUGIN_TARGET_NAME PLUGIN_NAME CONFIG PLUGIN_LOCATION)
        set_property(TARGET ${PLUGIN_TARGET_NAME} APPEND PROPERTY IMPORTED_CONFIGURATIONS ${CONFIG})

        set(imported_location "${_qt5Gui_install_prefix}/lib/qt/plugins/${PLUGIN_LOCATION}")
        _qt5_Gui_check_file_exists_static(${imported_location})
        set_target_properties(${PLUGIN_TARGET_NAME} PROPERTIES
            "IMPORTED_LOCATION_${CONFIG}" ${imported_location}
        )
        set_property(TARGET ${TARGET_NAME} APPEND PROPERTY STATIC_PLUGINS ${PLUGIN_NAME})
        get_filename_component(_PLUGIN_DIR ${PLUGIN_LOCATION} PATH)
        get_filename_component(_PLUGIN_DIR_NAME ${_PLUGIN_DIR} NAME)
        get_filename_component(_PLUGIN_NAME ${PLUGIN_LOCATION} NAME)
        string(REGEX REPLACE "^lib(.*)\\.a" "${_qt5Gui_install_prefix}/lib/qt/plugins/${_PLUGIN_DIR_NAME}/\\1.static.prl" PLUGIN_PRL_FILE_LOCATION ${_PLUGIN_NAME})
        if(NOT EXISTS ${PLUGIN_PRL_FILE_LOCATION})
            string(REGEX REPLACE "^lib(.*)\\.a" "${_qt5Gui_install_prefix}/lib/qt/plugins/${_PLUGIN_DIR_NAME}/\\1.prl" PLUGIN_PRL_FILE_LOCATION ${_PLUGIN_NAME})
        endif()
        if(NOT EXISTS ${PLUGIN_PRL_FILE_LOCATION})
            string(REGEX REPLACE "^lib(.*)\\.a" "${_qt5Gui_install_prefix}/lib/qt/plugins/${_PLUGIN_DIR_NAME}/lib\\1.prl" PLUGIN_PRL_FILE_LOCATION ${_PLUGIN_NAME})
        endif()
        if(NOT EXISTS ${PLUGIN_PRL_FILE_LOCATION})
            message(FATAL_ERROR The prl file containing dependencies of static plugin ${PLUGIN_TARGET_NAME} of ${TARGET_NAME} could not be found.)
        endif()
        _populate_Gui_plugin_target_dependencies_from_prl_file(${PLUGIN_TARGET_NAME} ${PLUGIN_PRL_FILE_LOCATION} ${CONFIG} "lib/qt/plugins" ${PLUGIN_LOCATION})

    endmacro()

    if(pluginTargets)
        foreach(pluginTarget ${pluginTargets})
            include(${pluginTarget})
        endforeach()
    endif()

    set(_Qt5Gui_PRIVATE_DIRS_EXIST TRUE)
    foreach (_Qt5Gui_PRIVATE_DIR ${${QT_VARIANT_PREFIX}Qt5Gui_OWN_PRIVATE_INCLUDE_DIRS})
        if (NOT EXISTS ${_Qt5Gui_PRIVATE_DIR})
            set(_Qt5Gui_PRIVATE_DIRS_EXIST FALSE)
        endif()
    endforeach()

    if (_Qt5Gui_PRIVATE_DIRS_EXIST)
        add_library(${TARGET_NAME}Private INTERFACE IMPORTED)
        set_property(TARGET ${TARGET_NAME}Private PROPERTY
            INTERFACE_INCLUDE_DIRECTORIES ${${QT_VARIANT_PREFIX}Qt5Gui_OWN_PRIVATE_INCLUDE_DIRS}
        )
        set(_Qt5Gui_PRIVATEDEPS)
        foreach(dep ${_Qt5Gui_LIB_DEPENDENCIES})
            if (TARGET ${dep}Private)
                list(APPEND _Qt5Gui_PRIVATEDEPS ${dep}Private)
            endif()
        endforeach()
        _qt5_add_dependencies(${TARGET_NAME}Private ALL
            "${TARGET_NAME};${_Qt5Gui_PRIVATEDEPS}")
    endif()

    _populate_Gui_target_properties_static(${TARGET_NAME} RELEASE "libQt5Gui.a" "" )


    if (EXISTS "${_qt5Gui_install_prefix}/lib/libQt5Guid.a" )
        _populate_Gui_target_properties_static(${TARGET_NAME} DEBUG "libQt5Guid.a" "" )
    endif()


    include("${CMAKE_CURRENT_LIST_DIR}/../${QT_VARIANT_PREFIX}Qt5Gui/${QT_VARIANT_PREFIX}Qt5GuiConfigExtras.cmake")

_qt5_Gui_check_file_exists_static("${CMAKE_CURRENT_LIST_DIR}/../${QT_VARIANT_PREFIX}Qt5Gui/${QT_VARIANT_PREFIX}Qt5GuiConfigVersion.cmake")

endif()
